==> optaplanner-examples-7.30.0.Final-redhat-00003-sources.jar: org/optaplanner/examples/cheaptime/domain/solver/TaskAssignmentDifficultyComparator.java <==
/*
 * Copyright 2014 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.optaplanner.examples.cheaptime.domain.solver;

import java.io.Serializable;
import java.util.Comparator;

import org.optaplanner.examples.cheaptime.domain.Task;
import org.optaplanner.examples.cheaptime.domain.TaskAssignment;

public class TaskAssignmentDifficultyComparator implements Comparator<TaskAssignment>, Serializable {

    private static final Comparator<Task> TASK_COMPARATOR = Comparator.comparingInt(Task::getResourceUsageMultiplicand)
            .thenComparingLong(Task::getPowerConsumptionMicros)
            .thenComparingInt(Task::getDuration);
    private static final Comparator<TaskAssignment> COMPARATOR =
            Comparator.comparing(TaskAssignment::getTask, TASK_COMPARATOR)
                    .thenComparingLong(TaskAssignment::getId);

    @Override
    public int compare(TaskAssignment a, TaskAssignment b) {
        return COMPARATOR.compare(a, b);
    }
}

==> optaplanner-examples-7.44.0.Final-redhat-00003-sources.jar: org/optaplanner/examples/cheaptime/domain/solver/TaskAssignmentDifficultyComparator.java <==
/*
 * Copyright 2014 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.optaplanner.examples.cheaptime.domain.solver;

import java.io.Serializable;
import java.util.Comparator;

import org.optaplanner.examples.cheaptime.domain.Task;
import org.optaplanner.examples.cheaptime.domain.TaskAssignment;

public class TaskAssignmentDifficultyComparator implements Comparator<TaskAssignment>, Serializable {

    private static final Comparator<Task> TASK_COMPARATOR = Comparator.comparingInt(Task::getResourceUsageMultiplicand)
            .thenComparingLong(Task::getPowerConsumptionMicros)
            .thenComparingInt(Task::getDuration);
    private static final Comparator<TaskAssignment> COMPARATOR = Comparator.comparing(TaskAssignment::getTask, TASK_COMPARATOR)
            .thenComparingLong(TaskAssignment::getId);

    @Override
    public int compare(TaskAssignment a, TaskAssignment b) {
        return COMPARATOR.compare(a, b);
    }
}
